### Name: equate
### Title: Linear and Equipercentile Equating
### Aliases: equate print.equate
### Keywords: methods

### ** Examples

# random groups equating for (1) mean, (2) linear, 
# (3) equipercentile, and (4) equipercentile with 
# loglinear smoothing:
rscale <- ACTmath[,1]
rx <- freqtab(ACTmath[,2],rscale,addclass=TRUE)
ry <- freqtab(ACTmath[,3],rscale,addclass=TRUE)
set.seed(2007)

req1 <- equate(rx,ry,type="m",bootse=TRUE,reps=100)
req2 <- equate(rx,ry,type="l",bootse=TRUE,reps=100)
req3 <- equate(rx,ry,type="e",bootse=TRUE,reps=100)
req4 <- equate(rx,ry,type="e",bootse=TRUE,reps=100,
  smooth="loglin",degree=3)

# compare equated scores:
cbind(rscale,mean=req1$conc[,2],linear=req2$conc[,2],
  equip=req3$conc[,2],equipS=req4$conc[,2])

# compare boostrap standard errors:
cbind(rscale,linear=req2$see,equip=req3$see,equipS=req4$see)

# nonequivalent groups design for (1) Tucker linear, and
# (2-3) frequency estimation with weights of 0 and 1
nscale <- 0:36
vscale <- 0:12
nx <- freqtab(KBneat$x[,1],nscale,KBneat$x[,2],vscale)
ny <- freqtab(KBneat$y[,1],nscale,KBneat$y[,2],vscale)

neq1 <- equate(nx,ny,type="Linear",method="Tuck",w=1)
neq2 <- equate(nx,ny,type="equip",method="freq",w=1)
neq3 <- equate(nx,ny,type="equip",method="freq",w=0)

# compare equated scores:
cbind(nscale,Tucker=neq1$conc[,2],FEw1=neq2$conc[,2],
  FEw0=neq3$conc[,2])



